==> resources-0.3.7.tgz: package/README.md <==
# resources - prerelease 

resources for any occasion 

 - [account](https://github.com/bigcompany/resources/tree/master/account) for managing accounts
 - [admin](https://github.com/bigcompany/resources/tree/master/admin) a web based admin panel
 - [analytics](https://github.com/bigcompany/resources/tree/master/analytics) real-time analytics by google
 - [api](https://github.com/bigcompany/resources/tree/master/api) provides a web API for interacting with resources
 - [calculator](https://github.com/bigcompany/resources/tree/master/calculator) a basic calculator
 - [cli](https://github.com/bigcompany/resources/tree/master/cli) provides a command line interface
 - [creature](https://github.com/bigcompany/resources/tree/master/creature) example resource for creatures like dragons, unicorns, and ponies
 - [cron](https://github.com/bigcompany/resources/tree/master/cron) for managing cron jobs
 - [datasource](https://github.com/bigcompany/resources/tree/master/datasource) perists resources to data storage engines
 - [docs](https://github.com/bigcompany/resources/tree/master/docs) for generating documentation
 - [email](https://github.com/bigcompany/resources/tree/master/email) for sending emails
 - [forms](https://github.com/bigcompany/resources/tree/master/forms) for generating HTML forms
 - [github](https://github.com/bigcompany/resources/tree/master/github) for interacting with the Github.com API
 - [hook](https://github.com/bigcompany/resources/tree/master/hook) for managing event hooks ( IF this THEN that )
 - [http](https://github.com/bigcompany/resources/tree/master/http) provides an HTTP API
 - [irc](https://github.com/bigcompany/resources/tree/master/irc) for managing communication with irc
 - [mesh](https://github.com/bigcompany/resources/tree/master/mesh) provides a distributed p2p event emitter mesh
 - [node](https://github.com/bigcompany/resources/tree/master/node) for managing nodes
 - [oauth](https://github.com/bigcompany/resources/tree/master/oauth) for managing oauth providers and sessions
 - [page](https://github.com/bigcompany/resources/tree/master/page) for representing HTML pages
 - [permissions](https://github.com/bigcompany/resources/tree/master/permissions) for managing permissions
 - [queue](https://github.com/bigcompany/resources/tree/master/queue) a queue for resource events
 - [repl](https://github.com/bigcompany/resources/tree/master/repl) enables an interactive Read-Eval-Print-Loop ( REPL )
 - [replication](https://github.com/bigcompany/resources/tree/master/replication) for managing and keeping track of replication events
 - [replicator](https://github.com/bigcompany/resources/tree/master/replicator) provides an application replication API for resource based apps
 - [resource](https://github.com/bigcompany/resources/tree/master/resource) meta-resource for describing and creating new resources
 - [socket](https://github.com/bigcompany/resources/tree/master/socket) socket.io websocket resource
 - [ssh](https://github.com/bigcompany/resources/tree/master/ssh) ssh interface resource
 - [stdin](https://github.com/bigcompany/resources/tree/master/stdin) allows application to listen for input from STDIN
 - [stdout](https://github.com/bigcompany/resources/tree/master/stdout) outputs all events as new-line delimited JSON fragments to STDOUT
 - [system](https://github.com/bigcompany/resources/tree/master/system) for interacting with the operating system
 - [tag](https://github.com/bigcompany/resources/tree/master/tag) a simple hierarchical tagging system
 - [twitter](https://github.com/bigcompany/resources/tree/master/twitter) for interacting with the Twitter API
 - [video](https://github.com/bigcompany/resources/tree/master/video) for managing online digital videos
 - [view](https://github.com/bigcompany/resources/tree/master/view) for managing views
 - [virtualhost](https://github.com/bigcompany/resources/tree/master/virtualhost) provides virtual hosts

==> resources-0.3.8-1.tgz: package/README.md <==
# resources - prerelease 

resources for any occasion 

 - [account](https://github.com/bigcompany/resources/tree/master/account) for managing accounts
 - [admin](https://github.com/bigcompany/resources/tree/master/admin) a web based admin panel
 - [analytics](https://github.com/bigcompany/resources/tree/master/analytics) real-time analytics by google
 - [api](https://github.com/bigcompany/resources/tree/master/api) provides a web API for interacting with resources
 - [calculator](https://github.com/bigcompany/resources/tree/master/calculator) a basic calculator
 - [cli](https://github.com/bigcompany/resources/tree/master/cli) provides a command line interface
 - [config](https://github.com/bigcompany/resources/tree/master/config) 
 - [creature](https://github.com/bigcompany/resources/tree/master/creature) example resource for creatures like dragons, unicorns, and ponies
 - [cron](https://github.com/bigcompany/resources/tree/master/cron) for managing cron jobs
 - [datasource](https://github.com/bigcompany/resources/tree/master/datasource) perists resources to data storage engines
 - [docs](https://github.com/bigcompany/resources/tree/master/docs) for generating documentation
 - [email](https://github.com/bigcompany/resources/tree/master/email) for sending emails
 - [forms](https://github.com/bigcompany/resources/tree/master/forms) for generating HTML forms
 - [github](https://github.com/bigcompany/resources/tree/master/github) for interacting with the Github.com API
 - [hook](https://github.com/bigcompany/resources/tree/master/hook) for managing event hooks ( IF this THEN that )
 - [http](https://github.com/bigcompany/resources/tree/master/http) provides an HTTP API
 - [irc](https://github.com/bigcompany/resources/tree/master/irc) for managing communication with irc
 - [mesh](https://github.com/bigcompany/resources/tree/master/mesh) provides a distributed p2p event emitter mesh
 - [node](https://github.com/bigcompany/resources/tree/master/node) for managing nodes
 - [oauth](https://github.com/bigcompany/resources/tree/master/oauth) for managing oauth providers and sessions
 - [page](https://github.com/bigcompany/resources/tree/master/page) for representing HTML pages
 - [permissions](https://github.com/bigcompany/resources/tree/master/permissions) for managing permissions
 - [queue](https://github.com/bigcompany/resources/tree/master/queue) a queue for resource events
 - [repl](https://github.com/bigcompany/resources/tree/master/repl) enables an interactive Read-Eval-Print-Loop ( REPL )
 - [replication](https://github.com/bigcompany/resources/tree/master/replication) for managing and keeping track of replication events
 - [replicator](https://github.com/bigcompany/resources/tree/master/replicator) provides an application replication API for resource based apps
 - [resource](https://github.com/bigcompany/resources/tree/master/resource) meta-resource for describing and creating new resources
 - [socket](https://github.com/bigcompany/resources/tree/master/socket) websockets resource
 - [ssh](https://github.com/bigcompany/resources/tree/master/ssh) ssh interface resource
 - [stdin](https://github.com/bigcompany/resources/tree/master/stdin) allows application to listen for input from STDIN
 - [stdout](https://github.com/bigcompany/resources/tree/master/stdout) outputs all events as new-line delimited JSON fragments to STDOUT
 - [system](https://github.com/bigcompany/resources/tree/master/system) for interacting with the operating system
 - [tag](https://github.com/bigcompany/resources/tree/master/tag) a simple hierarchical tagging system
 - [twitter](https://github.com/bigcompany/resources/tree/master/twitter) for interacting with the Twitter API
 - [video](https://github.com/bigcompany/resources/tree/master/video) for managing online digital videos
 - [view](https://github.com/bigcompany/resources/tree/master/view) for managing views
 - [virtualhost](https://github.com/bigcompany/resources/tree/master/virtualhost) provides virtual hosts
